@@ -3,7 +3,8 @@
 from __future__ import absolute_import
 
 from colorlog.colorlog import (
-    ColoredFormatter, escape_codes, default_log_colors)
+    ColoredFormatter, escape_codes, default_log_colors,
+    LevelFormatter)
 
 from colorlog.logging import (
     basicConfig, root, getLogger, log,
@@ -12,4 +13,4 @@ from colorlog.logging import (
 __all__ = ('ColoredFormatter', 'default_log_colors', 'escape_codes',
            'basicConfig', 'root', 'getLogger', 'debug', 'info', 'warning',
            'error', 'exception', 'critical', 'log', 'exception',
-           'StreamHandler')
+           'StreamHandler', 'LevelFormatter')
